@@ -28,15 +28,12 @@
 #include <swversion.h>
 
 //#ifdef USE_GTKMOZEMBED 
-#include "backend/gs_markupfiltmgr.h"
+//#include "backend/gs_markupfiltmgr.h"
 //#endif
 //#ifdef USE_SWORD_SVN
 #include <markupfiltmgr.h>
-//#endif
-
-#ifdef USE_SWORD_SVN
 #include <swlocale.h>
-#endif
+//#endif
 
 #include <gnome.h>
 #include <versekey.h>
@@ -71,13 +68,13 @@ BackEnd::BackEnd() {
 	display_mgr = new SWMgr(new GS_MarkupFilterMgr(FMT_HTMLHREF));
 
 #else	
-#ifdef USE_SWORD_SVN
+//#ifdef USE_SWORD_SVN
 	main_mgr = new SWMgr(new MarkupFilterMgr(FMT_HTMLHREF));
 	display_mgr = new SWMgr(new MarkupFilterMgr(FMT_HTMLHREF));
-#else
+/*#else
 	main_mgr = new SWMgr(new GS_MarkupFilterMgr(FMT_HTMLHREF));
 	display_mgr = new SWMgr(new GS_MarkupFilterMgr(FMT_HTMLHREF));
-#endif
+#endif*/
 #endif
 
 	
@@ -1195,7 +1192,7 @@ void BackEnd::init_language_map(void) {
 	languageMap[SWBuf("az")] = SWBuf(_("Azerbaijani")); /* done */
 	//languageMap[SWBuf("ba")] = SWBuf("Bashkir");
 	languageMap[SWBuf("be")] = SWBuf(_("Belarusian")); /* done */
-	languageMap[SWBuf("bg")] = SWBuf(_("Bulgrian")); /* done */
+	languageMap[SWBuf("bg")] = SWBuf(_("Bulgarian")); /* done */
 	//languageMap[SWBuf("bh")] = SWBuf("Bihari");
 	//languageMap[SWBuf("bi")] = SWBuf("Bislama");
 	//languageMap[SWBuf("bn")] = SWBuf("Bengali");
