@@ -22,7 +22,11 @@
 #ifndef __EDITOR_MENU_H_
 #define __EDITOR_MENU_H_
 
+#include <config.h>
+#ifndef USE_GTKHTML38
+
 #include <gnome.h>
+
 #include "editor/editor.h"
 
 void gui_new_activate(GtkMenuItem * menuitem, 
@@ -32,3 +36,4 @@ void on_save_activate(GtkMenuItem * menuitem,
 GtkWidget *gui_create_editor_popup(GSHTMLEditorControlData * ecd);
 
 #endif
+#endif
