@@ -2,7 +2,7 @@
  * GnomeSword Bible Study Tool
  * about_gnomesword.c - GnomeSword about dialog
  *
- * Copyright (C) 2000-2005 GnomeSword Developer Team
+ * Copyright (C) 2000-2006 GnomeSword Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@ static const gchar *authors[] = {
     "Carl Constantine",
     "Jp Robinson",
     "Andy Piper",
+     "Karl Kleinpaste",
     NULL
 };
   
@@ -49,6 +50,32 @@ static const gchar *documenters[] = {
 
 static gchar *translators = "Jan Paul Schmidt\nJorge Chacon\nDominique Corbex\nZdenko Podobn\nPavlo Bohmat";
 
+/******************************************************************************
+ * Name
+ *   on_dialog_response
+ *
+ * Synopsis
+ *   #include "gui/.h"
+ *
+ *   void on_dialog_response(GtkDialog * dialog, gint response_id, 
+					gpointer user_data)
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+static void on_dialog_response(GtkDialog * dialog, gint response_id, 
+					gpointer user_data)
+{
+	//if (response_id == GTK_RESPONSE_CLOSE) {
+		gtk_widget_destroy(GTK_WIDGET(dialog));
+	//}
+}
+
+
 /******************************************************************************
  * Name
  *   gui_create_about_gnomesword
@@ -75,13 +102,17 @@ gui_create_about_gnomesword(void)
   about1_logo_pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/about.png", &error);
 
   about1 = gtk_about_dialog_new ();
+  
+	g_signal_connect(about1, "response",
+			 G_CALLBACK(on_dialog_response), NULL);
+  
   gtk_about_dialog_set_name
           (GTK_ABOUT_DIALOG (about1), PACKAGE);
   gtk_about_dialog_set_version
           (GTK_ABOUT_DIALOG (about1), VERSION);
   gtk_about_dialog_set_copyright
           (GTK_ABOUT_DIALOG (about1),
-           _("Copyright 2000-2005 The GnomeSword Development Team"));
+           _("Copyright 2000-2006 The GnomeSword Development Team"));
   gtk_about_dialog_set_comments
           (GTK_ABOUT_DIALOG (about1),
            _("We would like to thank Troy Griffitts and all the other folks who have given us The SWORD Project."));
