@@ -503,30 +503,22 @@ GtkWidget *gui_create_bible_pane(void)
 {
 	GtkWidget *notebook_text;
 	GtkWidget *scrolledwindow;
-	GtkWidget *eventbox1;
+	//GtkWidget *eventbox1;
 	GtkWidget *frame;
 	
 	notebook_text = gtk_notebook_new();
 	gtk_widget_show(notebook_text);
-	/*gtk_notebook_set_show_border((GtkNotebook *)notebook_text,
-                                             TRUE);*/
 
 #ifdef USE_GTKMOZEMBED	
-	
-/*	frame = gtk_frame_new(NULL);
-	gtk_widget_show(frame);
-	gtk_container_add(GTK_CONTAINER(notebook_text), frame);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame), settings.shadow_type);*/
-	
-	eventbox1 = gtk_event_box_new ();
-	gtk_widget_show (eventbox1);
-	gtk_container_add(GTK_CONTAINER(notebook_text), eventbox1);
+	widgets.eventbox1 = gtk_event_box_new ();
+	gtk_widget_show (widgets.eventbox1);
+	gtk_container_add(GTK_CONTAINER(notebook_text), widgets.eventbox1);
 	widgets.html_text = embed_new(TEXT_TYPE);
 	gtk_widget_show(widgets.html_text);
-	gtk_container_add(GTK_CONTAINER(eventbox1),
+	gtk_container_add(GTK_CONTAINER(widgets.eventbox1),
 			 widgets.html_text);
 	
-	g_signal_connect ((gpointer) eventbox1, "enter_notify_event",
+	g_signal_connect ((gpointer) widgets.eventbox1, "enter_notify_event",
 		    G_CALLBACK (on_enter_notify_event),
 		    NULL);
 #else		
@@ -538,8 +530,6 @@ GtkWidget *gui_create_bible_pane(void)
 				       (scrolledwindow),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
-	/*gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow,
-                                             settings.shadow_type);*/
 	
 	widgets.html_text = gtk_html_new();
 	gtk_widget_show(widgets.html_text);
@@ -700,11 +690,8 @@ on_unlock_module_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 //	cipher_old = get_cipher_key(settings.MainWindowModule);
 	cipher_key = gui_add_cipher_key(settings.MainWindowModule, cipher_old);
-	if (cipher_key) {
-		main_locked_module_display(widgets.html_text,
-					     settings.MainWindowModule,
-					     cipher_key);
-	}
+	if (cipher_key) 
+		main_display_bible(settings.MainWindowModule, settings.currentverse);
 }
 
 
@@ -769,6 +756,9 @@ void gui_lookup_bibletext_selection(GtkMenuItem * menuitem,
 			(GtkEditable *)widgets.entry_dict,0,-1));
 #else
 	dict_key = gui_get_word_or_selection(widgets.html_text, FALSE);
+#ifdef DEBUG
+	g_message("gui_lookup_bibletext_selection\ndict_key: %s",dict_key);
+#endif
 #endif
 	if (dict_key && mod_name) {
 		main_display_dictionary(mod_name, dict_key);
