@@ -752,11 +752,8 @@ on_unlock_module_activate(GtkMenuItem * menuitem, gpointer user_data)
 //      cipher_old = get_cipher_key(settings.DictWindowModule);
 	cipher_key =
 	    gui_add_cipher_key(settings.DictWindowModule, cipher_old);
-	if (cipher_key) {
-		main_locked_module_display(widgets.html_dict,
-					   settings.DictWindowModule,
-					   cipher_key);
-	}
+	if (cipher_key)
+		main_display_dictionary(settings.DictWindowModule, settings.dictkey);
 }
 
 
