@@ -26,6 +26,10 @@
 #include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
 
+#ifdef USE_GTKMOZEMBED
+#include <gtkmozembed.h>
+#endif
+#include "main/embed.h"
 #include "main/sword.h"
 #include "main/settings.h"
 #include "main/xml.h"
@@ -82,6 +86,34 @@ void gui_show_hide_texts(gboolean choice)
 }
 
 
+/******************************************************************************
+ * Name
+ *  gui_show_hide_preview
+ *
+ * Synopsis
+ *   #include "gui/main_window.h"
+ *
+ *   void gui_show_hide_preview(gboolean choice)
+ *
+ * Description
+ *    Show/hide bible texts
+ *
+ * Return value
+ *   void
+ */
+
+void gui_show_hide_preview(gboolean choice)
+{
+	settings.showpreview = choice;
+	if (choice == FALSE) {
+		gtk_widget_hide(widgets.vbox_previewer);
+	} else {
+		gtk_widget_show(widgets.vbox_previewer);
+	}
+	//gui_set_bible_comm_layout();
+}
+
+
 /******************************************************************************
  * Name
  *  gui_show_hide_comms
@@ -470,6 +502,7 @@ void create_mainwindow(void)
 	GtkWidget *label;
 	GtkWidget *scrolledwindow;
 	GtkWidget *box_book;
+	GtkWidget *frame;
 	/*
 	GTK_SHADOW_NONE
   	GTK_SHADOW_IN
@@ -625,14 +658,24 @@ void create_mainwindow(void)
 	/*
 	 * previewer
 	 */
-	vbox = gtk_vbox_new(FALSE, 0);
-	gtk_widget_show(vbox);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 1);
-	gtk_paned_pack2(GTK_PANED(widgets.vpaned), vbox, FALSE, TRUE);
+	widgets.vbox_previewer = gtk_vbox_new(FALSE, 0);
+	gtk_widget_show(widgets.vbox_previewer);
+	gtk_container_set_border_width (GTK_CONTAINER (widgets.vbox_previewer), 1);
+	gtk_paned_pack2(GTK_PANED(widgets.vpaned), widgets.vbox_previewer, FALSE, TRUE);
 	
+#ifdef USE_GTKMOZEMBED 
+	frame = gtk_frame_new(NULL);
+	gtk_widget_show(frame);
+	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
+	gtk_box_pack_start(GTK_BOX(widgets.vbox_previewer), frame, 
+				TRUE, TRUE,
+			   	0);
+	sidebar.html_viewer_widget = embed_new(VIEWER_TYPE);
+	gtk_container_add(GTK_CONTAINER(frame), sidebar.html_viewer_widget);
+#else
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
-	gtk_box_pack_start(GTK_BOX(vbox), scrolledwindow, TRUE, TRUE,
+	gtk_box_pack_start(GTK_BOX(widgets.vbox_previewer), scrolledwindow, TRUE, TRUE,
 			   0);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
 				       (scrolledwindow),
@@ -641,16 +684,16 @@ void create_mainwindow(void)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolledwindow,
 					    settings.shadow_type);
-
 	sidebar.html_viewer_widget = gtk_html_new();
-	gtk_widget_show(sidebar.html_viewer_widget);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow),
 			  sidebar.html_viewer_widget);
-
 	g_signal_connect(GTK_OBJECT(sidebar.html_viewer_widget),
 			 "link_clicked", G_CALLBACK(gui_link_clicked),
 			 NULL);
+#endif
 
+	gtk_widget_show(sidebar.html_viewer_widget);
+			  
 	/*
 	 * commentary/book notebook
 	 */
@@ -763,6 +806,24 @@ void create_mainwindow(void)
                                              settings.gs_hight);
 }
 
+/*
+void new_main_window(void)
+{
+	gchar *glade_file;
+	GladeXML *gxml;
+	
+	glade_file =
+	    gui_general_user_file("main-window.glade", FALSE);
+	g_return_if_fail(glade_file != NULL);
+	g_message(glade_file);
+
+//	** build the widget **
+	gxml = glade_xml_new(glade_file, "main-window", NULL);
+
+	
+	
+}
+
 
 /******************************************************************************
  * Name
