@@ -1149,37 +1149,14 @@ static gboolean tree_key_press_cb(GtkWidget * widget,
 
 static void create_search_results_page(GtkWidget * notebook)
 {
-	GtkWidget *vbox;
-	GtkWidget *frame;
-	GtkWidget *scrolledwindow;
-//      GtkWidget *vpaned_srch_rslt;
-//      GtkWidget *frame3;
 	GtkWidget *scrolledwindow3;
-//      GtkWidget *frame4;
-//      GtkWidget *scrolledwindow4;
 	GtkListStore *model;
 	GtkTreeSelection *selection;
 	GtkWidget *menu = create_results_menu();
 
-	vbox = gtk_vbox_new(FALSE, 0);
-	gtk_widget_show(vbox);
-	gtk_container_add(GTK_CONTAINER(notebook), vbox);
-/*	
-	vpaned_srch_rslt = gtk_vpaned_new();
-	gtk_widget_show(vpaned_srch_rslt);
-	gtk_box_pack_start(GTK_BOX(vbox), vpaned_srch_rslt, TRUE,
-			   TRUE, 0);
-	if (settings.verselist_toppane_height == 0)
-		settings.verselist_toppane_height = 100;
-	gtk_paned_set_position(GTK_PANED(vpaned_srch_rslt),
-				settings.verselist_toppane_height);
-*/
 	scrolledwindow3 = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow3);
-	gtk_box_pack_start(GTK_BOX(vbox), scrolledwindow3, TRUE,
-			   TRUE, 0);
-	/*gtk_paned_pack1(GTK_PANED(vpaned_srch_rslt), scrolledwindow3, TRUE,
-	   TRUE); */
+	gtk_container_add(GTK_CONTAINER(notebook), scrolledwindow3);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
 				       (scrolledwindow3),
 				       GTK_POLICY_AUTOMATIC,
@@ -1209,42 +1186,14 @@ static void create_search_results_page(GtkWidget * notebook)
 
 	gnome_popup_menu_attach(menu, sidebar.results_list, NULL);
 	gnome_app_install_menu_hints(GNOME_APP(widgets.app),
-				     results_menu_uiinfo);
-/*
-	scrolledwindow4 = gtk_scrolled_window_new(NULL, NULL);
-	gtk_widget_show(scrolledwindow4);
-	gtk_paned_pack2(GTK_PANED(vpaned_srch_rslt), scrolledwindow4, TRUE,
-			TRUE);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
-				       (scrolledwindow4),
-				       GTK_POLICY_NEVER,
-				       GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow4,
-                                             settings.shadow_type);
-
-
-	sidebar.html_widget = gtk_html_new();
-	gtk_widget_show(sidebar.html_widget);
-	gtk_container_add(GTK_CONTAINER(scrolledwindow4),
-			  sidebar.html_widget);
-	gtk_html_load_empty(GTK_HTML(sidebar.html_widget));
-*/
+				     results_menu_uiinfo);				     
+				     
 	g_signal_connect((gpointer) sidebar.results_list,
 			 "key_press_event",
 			 G_CALLBACK(tree_key_press_cb), NULL);
 	g_signal_connect((gpointer) selection,
 			 "changed",
 			 G_CALLBACK(tree_selection_changed_cb), NULL);
-	/*
-	   g_signal_connect(GTK_OBJECT(sidebar.html_widget), 
-	   "link_clicked",
-	   G_CALLBACK(link_clicked),
-	   NULL);
-	   g_signal_connect((gpointer) sidebar.html_widget,
-	   "button_release_event",
-	   G_CALLBACK(on_button_release_event),
-	   sidebar.html_widget);
-	 */
 	g_signal_connect((gpointer) sidebar.results_list,
 			 "button_release_event",
 			 G_CALLBACK(gui_verselist_button_release_event),
@@ -1253,12 +1202,6 @@ static void create_search_results_page(GtkWidget * notebook)
 			 "button_press_event",
 			 G_CALLBACK(on_treeview_button_press_event),
 			 NULL);
-	/*
-	   g_signal_connect(GTK_OBJECT(vpaned_srch_rslt),
-	   "button_release_event",
-	   G_CALLBACK(vpaned_srch_rslt_button_release_event),
-	   NULL);
-	 */
 }
 
 
