@@ -113,12 +113,14 @@ void set_current_tab (PASSAGE_TAB_INFO *pt)
 	PASSAGE_TAB_INFO *ot = cur_passage_tab;
 	
 	if (ot != NULL && ot->button_close != NULL) {
+		//gtk_widget_set_sensitive(ot->button_close, FALSE);
 		gtk_widget_hide (ot->button_close);
 		gtk_widget_show (ot->close_pixmap);
 	}
 	cur_passage_tab = pt;
 	if (pt != NULL && pt->button_close != NULL) {
 		main_update_tab_history_menu((PASSAGE_TAB_INFO*)pt);
+		//gtk_widget_set_sensitive(pt->button_close, TRUE);
 		gtk_widget_show (pt->button_close);
 		gtk_widget_hide (pt->close_pixmap);
 	}
@@ -227,8 +229,8 @@ void gui_save_tabs(const gchar *filename)
 	section_node = xmlNewChild(root_node, NULL,
 				   (const xmlChar *) "tabs", NULL);
 	
-	tmp = g_list_first(passage_list);
-	while (tmp != NULL) {
+	for (tmp = g_list_first(passage_list); tmp != NULL; tmp = g_list_next(tmp)) {
+
 		pt = (PASSAGE_TAB_INFO*) tmp->data;
 		
 		cur_node = xmlNewChild(section_node,
@@ -249,7 +251,6 @@ void gui_save_tabs(const gchar *filename)
 				(const xmlChar *)pt->book_offset);		
 		xmlNewProp(cur_node, (const xmlChar *)"comm_showing", 
 				(const xmlChar *)true_false2yes_no(pt->comm_showing));
-		tmp = g_list_next(tmp);
 	}
 	xmlSaveFormatFile(file, xml_doc,1);
 	xmlFreeDoc(xml_doc);
@@ -393,10 +394,18 @@ void gui_load_tabs(const gchar *filename)
 			settings.dictkey = g_strdup(pt->dictlex_key);
 			settings.book_offset = atol(pt->book_offset);
 		}
-	}
-	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_main),
-			gtk_notebook_page_num(GTK_NOTEBOOK(widgets.notebook_main), pt->page_widget));
+	}			//gtk_notebook_page_num(GTK_NOTEBOOK(widgets.notebook_main), pt->page_widget));
 	set_current_tab(pt);
+	
+/*	if(pt->comm_showing)
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(
+					widgets.notebook_comm_book),
+					0);
+	else
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(
+					widgets.notebook_comm_book),
+					1);	
+*/
 }
 
 
@@ -459,10 +468,11 @@ static GtkWidget* tab_widget_new(PASSAGE_TAB_INFO *tbinf, const gchar *label_tex
 	gtk_widget_set_usize (tbinf->button_close, 16, 16);
 	
 	tbinf->close_pixmap = gtk_image_new_from_stock(GTK_STOCK_CLOSE, 
-					GTK_ICON_SIZE_SMALL_TOOLBAR);
+					GTK_ICON_SIZE_MENU);
 	gtk_widget_size_request (tbinf->button_close, &r);
 	gtk_widget_set_usize (tbinf->close_pixmap, r.width, r.height);
 	gtk_widget_set_sensitive(tbinf->close_pixmap, FALSE);
+	gtk_widget_show(tbinf->close_pixmap);
 	
 	tbinf->tab_label = GTK_LABEL(gtk_label_new (label_text));
 	gtk_widget_show (GTK_WIDGET(tbinf->tab_label));
@@ -476,7 +486,6 @@ static GtkWidget* tab_widget_new(PASSAGE_TAB_INFO *tbinf, const gchar *label_tex
 	gtk_widget_modify_fg (tbinf->button_close, GTK_STATE_ACTIVE, &color);
 	gtk_widget_modify_fg (tbinf->button_close, GTK_STATE_PRELIGHT, &color);
 	gtk_widget_modify_fg (tbinf->button_close, GTK_STATE_SELECTED, &color);
-	gtk_widget_show(tbinf->button_close);
 	
 	box = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(box), GTK_WIDGET(tbinf->tab_label), TRUE, 
@@ -566,35 +575,65 @@ void gui_notebook_main_switch_page(GtkNotebook * notebook,
  * Synopsis
  *   #include "tabbed_browser.h"
  *
- *   void gui_set_tab_label(TABED_PAGE *p)	
+ *   void gui_set_tab_label(const char *key)	
  *
  * Description
- *   sets current tab label to current verse
+ *   sets tab label(s) to current verse.
+ *   dependent on pinnedtabs setting, either just cur or all.
  *
  * Return value
  *   void
  */
  
 void gui_set_tab_label(const gchar * key)
+{
+	if (settings.pinnedtabs) {
+		GList *tmp = NULL;
+		for (tmp = g_list_first(passage_list); tmp != NULL; tmp = g_list_next(tmp))
+			gui_set_named_tab_label(key, (PASSAGE_TAB_INFO*)tmp->data);
+	}
+	else
+	{
+		gui_set_named_tab_label(key, cur_passage_tab);
+	}
+}
+
+/******************************************************************************
+ * Name
+ *  gui_set_named_tab_label
+ *
+ * Synopsis
+ *   #include "tabbed_browser.h"
+ *
+ *   void gui_set_named_tab_label(const char *key, PASSAGE_TAB_INFO *pt)	
+ *
+ * Description
+ *   sets specified tab label to current verse
+ *
+ * Return value
+ *   void
+ */
+ 
+void gui_set_named_tab_label(const gchar * key, PASSAGE_TAB_INFO *pt)
 {
 	GString *str = g_string_new(NULL);
 	
-	if(cur_passage_tab->text_commentary_key)
-		g_free(cur_passage_tab->text_commentary_key);
-	cur_passage_tab->text_commentary_key = g_strdup(key);
+	if (pt->text_commentary_key)
+		g_free(pt->text_commentary_key);
+	pt->text_commentary_key = g_strdup(key);
 		
 	g_string_printf(str,"%s: %s",
-				cur_passage_tab->text_mod,
-				cur_passage_tab->text_commentary_key); 
-	gtk_label_set_text (cur_passage_tab->tab_label,str->str);
+				pt->text_mod,
+				pt->text_commentary_key); 
+	gtk_label_set_text (pt->tab_label,str->str);
 #ifdef DEBUG 
 	g_print("label = %s\n",str->str);	
 #endif
 	gtk_notebook_set_menu_label_text(
 					GTK_NOTEBOOK(widgets.notebook_main),
-                                        cur_passage_tab->page_widget,
+                                        pt->page_widget,
                                             str->str );
-	main_add_tab_history_item((PASSAGE_TAB_INFO*)cur_passage_tab);
+	main_add_tab_history_item((PASSAGE_TAB_INFO*)pt);
 	g_string_free(str,TRUE);
 }
 
@@ -632,12 +671,14 @@ void gui_update_tab_struct(const gchar * text_mod,
 		cur_passage_tab->text_mod = g_strdup(text_mod);	
 				
 	}
+	//g_message("commentary_mod = %s",commentary_mod);
 	if(commentary_mod) {
 		cur_passage_tab->comm_showing = comm_showing;
 		if(cur_passage_tab->commentary_mod)
 			g_free(cur_passage_tab->commentary_mod);
 		cur_passage_tab->commentary_mod = g_strdup(commentary_mod);		
 	} 
+	//g_message("cur_passage_tab->commentary_mod = %s",cur_passage_tab->commentary_mod);
 	if(dictlex_mod) {
 		if(cur_passage_tab->dictlex_mod)
 			g_free(cur_passage_tab->dictlex_mod);
@@ -929,6 +970,10 @@ void gui_notebook_main_setup(void)
 	//show the new tab button here instead of in main_window.c so it
 	//doesn't get shown if !settings.browsing
 	gtk_widget_show(widgets.button_new_tab);
+	gui_notebook_main_switch_page(GTK_NOTEBOOK(widgets.notebook_main),
+					 NULL,
+					 settings.tab_page, 
+					&passage_list);
 }
 
 /******************************************************************************
