@@ -25,6 +25,27 @@
 #ifdef __cplusplus
 extern "C" {
 #endif	
+#include <gnome.h>
+	
+typedef struct _sidebar_search SIDESEARCH;
+struct _sidebar_search {
+	GtkWidget *rrbUseBounds;
+ 	GtkWidget *entrySearch;
+ 	GtkWidget *entryLower;
+ 	GtkWidget *entryUpper;
+	GtkWidget *rbMultiword;
+ 	GtkWidget *rbRegExp;
+	GtkWidget *rbNoScope;
+ 	GtkWidget *rbLastSearch;
+ 	GtkWidget *rbPhraseSearch;
+ 	GtkWidget *ckbCaseSensitive;
+ 	GtkWidget *progressbar_search;
+ 	GtkWidget *frame5;
+ 	GtkWidget *frame_module;
+ 	GtkWidget *radiobutton_search_text;
+ 	GtkWidget *radiobutton_search_comm;
+};
+extern SIDESEARCH ss;
 	
 void gui_search_update_sidebar(char percent, void *userData);
 void gui_create_search_sidebar(void);
