@@ -33,6 +33,10 @@
 #include <regex.h>
 #include <string.h>
 
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <errno.h>
+
 #ifdef USE_GTKMOZEMBED
 #include <gtkmozembed.h>
 #include <nsIDOMHTMLAnchorElement.h>
@@ -52,6 +56,7 @@ extern "C" {
 
 #include "gui/utilities.h"
 #include "gui/widgets.h"
+#include "gui/dialog.h"
 
 #include "backend/sword_main.hh"
 #include "backend/gs_osishtmlhref.h"
@@ -182,7 +187,7 @@ void GTKChapDisp::getVerseBefore(SWModule &imodule)
 			(mf->old_font_size)?mf->old_font_size:"+0", 
 			settings.bible_text_color);
 		
-		if((!strcmp(settings.MainWindowModule,"KJV"))  || (!strcmp(settings.MainWindowModule,"KJV2006")))
+		if((!strcmp(settings.MainWindowModule,"KJV")))
 			swbuf.appendFormatted("</font><div style=\"text-align: center\">%s<hr></div>", 
 					mod->Description());
 		else
@@ -204,9 +209,7 @@ void GTKChapDisp::getVerseBefore(SWModule &imodule)
 				"<font size=\"%s\" color=\"%s\">%d</font></A> ",
 				utf8_key,
 				0, 
-				(settings.versestyle)
-				?settings.verse_num_font_size
-				:"-2",
+				(settings.versestyle) ?settings.verse_num_font_size :"-2",
 				settings.bible_verse_num_color, 
 				key->Verse());
 		
@@ -216,10 +219,11 @@ void GTKChapDisp::getVerseBefore(SWModule &imodule)
 				(mf->old_font_size)?mf->old_font_size:"+0", 
 				settings.bible_text_color);		
 		//g_message(mod->getRawEntry());
-		if((!strcmp(settings.MainWindowModule,"KJV"))  || (!strcmp(settings.MainWindowModule,"KJV2006")))
+/*		if((!strcmp(settings.MainWindowModule,"KJV"))  || (!strcmp(settings.MainWindowModule,"KJV2006")))
 			swbuf.appendFormatted("%s</font><br><hr>",
 					(const char *)*mod);
-		else		
+		else	
+*/	
 			swbuf.appendFormatted(
 				"%s</font><br><hr><div style=\"text-align: center\"><b>%s %d</b></div>",
 					(const char *)*mod, _("Chapter"), chapter);
@@ -290,6 +294,179 @@ void GTKChapDisp::getVerseAfter(SWModule &imodule)
 	}
 }
 
+//
+// Read aloud some text, i.e. the current verse.
+// Text is cleaned of '"', <tokens>, "&symbols;", and *n/*x strings, then
+// scribbled out the local static socket with (SayText "...").
+// Non-zero verse param is prefixed onto supplied text.
+//
+void GTKChapDisp::ReadAloud(unsigned int verse, const char *suppliedtext)
+{
+	static int tts_socket = -1;	// no initial connection.
+	static int use_counter = -2;	// to shortcircuit early uses.
+
+	if (settings.readaloud) {
+		gchar *s, *t;
+
+		// setup for communication.
+		if (tts_socket < 0) {
+			struct sockaddr_in service;
+
+			if ((tts_socket = socket (AF_INET, SOCK_STREAM, 0)) < 0) {
+				char msg[128];
+				settings.readaloud = 0;
+				gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+							       (widgets.readaloud_item),
+							       settings.readaloud);
+
+				sprintf(msg, "ReadAloud disabled:\nsocket failed, %s",
+					strerror(errno));
+				gui_generic_warning(msg);
+				return;
+			}
+
+			// festival's port (1314) on localhost (127.0.0.1).
+			memset(&service, 0, sizeof service);
+			service.sin_family = AF_INET;
+			service.sin_port = htons(1314);
+			service.sin_addr.s_addr = htonl(0x7f000001);
+			if (connect(tts_socket, (const sockaddr *)&service,
+				    sizeof(service)) != 0) {
+				char msg[128];
+				sprintf(msg, "TTS unavailable: %s\nAttempting TTS restart",
+					strerror(errno));
+				system("festival --server &");
+				gui_generic_warning(msg);
+
+				if (connect(tts_socket, (const sockaddr *)&service,
+					    sizeof(service)) != 0) {
+					// it still didn't work -- missing.
+					close(tts_socket);
+					tts_socket = -1;
+					settings.readaloud = 0;
+					gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+								       (widgets.readaloud_item),
+								       settings.readaloud);
+
+					sprintf(msg, "%s\n%s, %s",
+						"TTS \"festival\" not started -- perhaps not installed",
+						"TTS connect failed", strerror(errno));
+					gui_generic_warning(msg);
+					return;
+				}
+			}
+		}
+
+		// avoid speaking the first *2* times.
+		// (2 Display() calls are made during startup.)
+		// though speaking may be intended, startup speech is annoying.
+		if (++use_counter < 1)
+			return;
+
+		GString *text = g_string_new(NULL);
+		if (verse != 0)
+			g_string_printf(text, "%d. ...  %s", verse, suppliedtext);
+			// use of ". ..." is to induce proper pauses.
+		else
+			g_string_printf(text, "%s", suppliedtext);
+#ifdef DEBUG
+		g_message("ReadAloud: dirty: %s\n", text->str);
+#endif
+
+		// clean: no quotes (conflict w/festival syntax).
+		for (s = strchr(text->str, '"'); s; s = strchr(s, '"'))
+			*s = ' ';
+
+		// clean: no <tokens>.
+		for (s = strchr(text->str, '<'); s; s = strchr(s, '<')) {
+			if (t = strchr(s, '>')) {
+				while (s <= t)
+					*(s++) = ' ';
+			} else {
+#ifdef DEBUG
+				g_message("ReadAloud: Unmatched <> in %s\n", s);
+#endif
+				goto out;
+			}
+		}
+
+		// clean: no &lt;...&gt; sequences.  (Strong's ref, "<1234>".)
+		for (s = strstr(text->str, "&lt;"); s; s = strstr(s, "&lt;")) {
+			if (t = strstr(s, "&gt;")) {
+				t += 3;
+				while (s <= t)
+					*(s++) = ' ';
+			} else {
+#ifdef DEBUG
+				g_message("ReadAloud: Unmatched &lt;&gt; in %s\n", s);
+#endif
+				goto out;
+			}
+		}
+		
+		// clean: no other &symbols;.
+		for (s = strchr(text->str, '&'); s; s = strchr(s, '&')) {
+			if (t = strchr(s, ';')) {
+				while (s <= t)
+					*(s++) = ' ';
+			} else {
+#ifdef DEBUG
+				g_message("ReadAloud: Incomplete &xxx; in %s\n", s);
+#endif
+				goto out;
+			}
+		}
+
+		// clean: no note/xref strings.
+		for (s = strstr(text->str, "*n"); s; s = strstr(s, "*n")) {
+			*(s++) = ' ';
+			*(s++) = ' ';
+		}
+		for (s = strstr(text->str, "*x"); s; s = strstr(s, "*x")) {
+			*(s++) = ' ';
+			*(s++) = ' ';
+		}
+#ifdef DEBUG
+		g_message("ReadAloud: clean: %s\n", text->str);
+#endif
+
+		// scribble clean text to the socket.
+		if ((write(tts_socket, "(SayText \"", 10) < 0)  ||
+		    (write(tts_socket, text->str, strlen(text->str)) < 0) ||
+		    (write(tts_socket, "\")\r\n", 4) < 0))
+		{
+			char msg[128];
+			shutdown(tts_socket, SHUT_RDWR);
+			close(tts_socket);
+			tts_socket = -1;
+			settings.readaloud = 0;
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+						       (widgets.readaloud_item),
+						       settings.readaloud);
+
+			sprintf(msg, "TTS disappeared?\nTTS write failed: %s",
+				strerror(errno));
+			gui_generic_warning(msg);
+		}
+
+	out:
+		g_string_free(text, TRUE);
+		return;
+
+	} else {
+
+		// Reading aloud is disabled.
+		// If we had been reading, shut it down.
+		if (tts_socket >= 0) {
+			shutdown(tts_socket, SHUT_RDWR);
+			close(tts_socket);
+			tts_socket = -1;
+		}
+		use_counter++;
+		return;
+	}
+}
+
 char GTKChapDisp::Display(SWModule &imodule) 
 {
 	VerseKey *key = (VerseKey *)(SWKey *)imodule;
@@ -359,7 +536,8 @@ char GTKChapDisp::Display(SWModule &imodule)
 		while((preverse 
 			= backend->get_entry_attribute("Heading","Preverse",
 							    heading)) != NULL) {
-			swbuf.appendFormatted("<br><b>%s</b><br><br>",preverse);
+			const char *preverse2 = imodule.RenderText(preverse);
+			swbuf.appendFormatted("<br><b>%s</b><br><br>",preverse2);
 			g_free(preverse);					     
 			++x;
 			sprintf(heading,"%d",x);
@@ -407,6 +585,9 @@ char GTKChapDisp::Display(SWModule &imodule)
 
 		swbuf += (const char *)imodule;		
 		buf = g_strdup_printf("%s",(const char *)imodule);
+
+		if (key->Verse() == curVerse)
+			GTKChapDisp::ReadAloud(curVerse, imodule);
 		
 		if (settings.versestyle) { 
 			if(g_strstr_len(buf,strlen(buf),"<!p>")) {
@@ -428,6 +609,12 @@ char GTKChapDisp::Display(SWModule &imodule)
 	}
 	swbuf = "";
 	getVerseAfter(imodule);	
+
+	// Reset the Bible location before GTK gets access:
+	// Mouse activity destroys this key, so we must be finished with it.
+	key->Book(curBook);
+	key->Chapter(curChapter);
+	key->Verse(curVerse);
 	
 	if(is_rtol) 
 		swbuf += ("</DIV></body></html>");
@@ -448,7 +635,6 @@ char GTKChapDisp::Display(SWModule &imodule)
 		g_free(buf);
 	}
 #else	
-	gtk_html_flush (html); 
 	if (was_editable)
 		gtk_html_set_editable(html, FALSE);
 	if (swbuf.length())
@@ -456,17 +642,13 @@ char GTKChapDisp::Display(SWModule &imodule)
 		//gtk_html_load_from_string(html,swbuf.c_str(),swbuf.length());
 	gtk_html_end(html,stream,status);
 	gtk_html_set_editable(html, was_editable);
-	if(curVerse > 1) {
-		buf = g_strdup_printf("%d", curVerse - 1);
+	if(curVerse > 2) {
+		buf = g_strdup_printf("%d", curVerse - 2);
 		gtk_html_jump_to_anchor(html, buf);
 		g_free(buf);
 	}
+	gtk_html_flush (html); 
 #endif
-	key->Verse(1);
-	key->Chapter(1);
-	key->Book(curBook);
-	key->Chapter(curChapter);
-	key->Verse(curVerse);
 	free_font(mf);	
 	g_free(ops);
 }
