@@ -80,6 +80,11 @@ struct _dialog_data {
 	GLOBAL_OPS *ops;
 };
 
+void main_dialogs_information_viewer(DIALOG_DATA * d, gchar * mod_name, 
+				     gchar * text, gchar * key,
+		             	     gchar * action ,gchar * type ,
+			     	     gchar * morph_text, gchar * morph);
+void main_dialogs_clear_viewer(DIALOG_DATA *d);
 void main_dialogs_add_children_to_tree(GtkTreeModel * model, GtkTreeIter iter,
 	  unsigned long offset, gboolean is_dialog, DIALOG_DATA * d);
 void main_dialogs_add_book_to_tree(GtkWidget * tree, gchar * mod_name, 
@@ -99,7 +104,7 @@ void main_dialogs_setup(void);
 void main_dialogs_shutdown(void);
 void main_free_on_destroy(DIALOG_DATA * vt);
 void main_dialog_goto_bookmark(const gchar * module, const gchar * key);
-void main_dialog_set_global_opt(gboolean choice);
+void main_dialog_set_global_opt(gpointer backend, gboolean choice);
 gint main_dialogs_url_handler(DIALOG_DATA * t, const gchar * url, gboolean clicked);
 DIALOG_DATA *main_dialogs_open( const gchar * mod_name,  const gchar * key);
 
