@@ -28,6 +28,9 @@ extern "C" {
 
 #include <glib-2.0/glib.h>
 
+void main_finds_verselist_selection_changed(GtkTreeSelection * selection, gpointer data);
+void main_selection_modules_lists_changed(GtkTreeSelection * selection, gpointer data);
+void main_selection_finds_list_changed(GtkTreeSelection *  selection, gpointer data);
 void main_comboboxentry2_changed(GtkComboBox * combobox, gpointer user_data);
 void main_dialog_search_percent_update(char percent, void *userData);
 void main_range_text_changed(GtkEditable * editable);	
@@ -37,10 +40,8 @@ void main_delete_range(void);
 void main_add_modlist_to_label(void);
 void main_change_mods_select_label(char *mod_name);
 void main_delete_module(GtkTreeView *treeview);
-void main_selection_modules_lists_changed(GtkTreeSelection *
-				    selection, gpointer data);
-void main_mod_selection_changed(GtkTreeSelection * selection,
-				     GtkWidget * tree_widget);
+void main_selection_modules_lists_changed(GtkTreeSelection * selection, gpointer data);
+void main_mod_selection_changed(GtkTreeSelection * selection, GtkWidget * tree_widget);
 void main_do_dialog_search(void);
 void main_open_search_dialog(void);
 void main_close_search_dialog(void);
