@@ -168,6 +168,18 @@ int settings_init(int new_configs, int new_bookmarks)
 		g_print("\nFirst Run: need to create settings!\n");
 #endif
 		settings.first_run = TRUE;
+
+		sword_dir = g_strdup_printf("%s/%s", settings.homedir, ".sword/modules/texts");
+		if (access(sword_dir, F_OK) == -1) {
+			gui_generic_warning
+			    ("Must invoke install manager for 1 Bible text.\nThis may take a minute or two.");
+			backend_init_module_mgr_config();
+			system("cd ; cd .sword ; installmgr -r crosswire ; installmgr -ri crosswire ESV ; rm -f dirlist");
+			gui_generic_warning
+			    ("Bible text installation complete");
+		}
+		g_free(sword_dir);
+
 		main_init_lists();
 		xml_create_settings_file(settings.fnconfigure);
 		//retval = gui_first_run();
@@ -333,6 +345,13 @@ void load_settings_structure(void)
 		settings.book_offset = 0;
 	}
 
+	if(xml_get_value("tab", "page"))
+		settings.tab_page = atol(xml_get_value("tab", "page"));
+	else {
+		xml_add_new_item_to_section("tab", "page", "0");
+		settings.tab_page = 0;
+	}
+
 	settings.sidebar_width =
 		atoi(xml_get_value("layout", "shortcutbar"));
 	if(xml_get_value("layout", "vltoppaneheight"))
@@ -442,6 +461,23 @@ void load_settings_structure(void)
 	settings.showdevotional =
 	    atoi(xml_get_value("misc", "dailydevotional"));
 	settings.versestyle = atoi(xml_get_value("misc", "versestyle"));
+
+	buf = xml_get_value("misc", "pinnedtabs");
+	if (buf)
+		settings.pinnedtabs = atoi(buf);
+	else {
+		xml_add_new_item_to_section("misc", "pinnedtabs", "0");
+		settings.pinnedtabs = 0;
+	}
+
+	buf = xml_get_value("misc", "readaloud");
+	if (buf)
+		settings.readaloud = atoi(buf);
+	else {
+		xml_add_new_item_to_section("misc", "readaloud", "0");
+		settings.readaloud = 0;
+	}
+
 	settings.usedefault = atoi(xml_get_value("misc", "usedefault"));
 	
 		
