@@ -87,7 +87,7 @@ struct _settings {
 		whichwindow,      	/* which of the main form html windows is active */
 		intCurVerse,    /* detached parallel current verse */
 		parallel_page,   /* parallel workbook page number */
-		studypad_page,   /* studypad workbook page number */
+		tab_page,   /* studypad workbook page number */
 		percomm_page;   /* percomm editor workbook page number */
 						
 	int   
@@ -102,7 +102,9 @@ struct _settings {
 		cantillationmarksint, //-- check menu state parallel mods
 	        footnotesint, //-- check menu state parallel mods
 		greekaccentsint, //-- check menu state parallel mods
-	        versestyle, /* use verse style if true of paragraph style if not */
+	        versestyle, /* use verse style if true or paragraph style if not */
+	        pinnedtabs, /* all tabs are pinned together, moving in concert */
+	        readaloud, /* pass text through (existing) "festival -server" */
 	        parallelpage, /* display parallel page */
 	        autosavepersonalcomments, /* auto save personal notes */
 	        formatpercom, /* use html to format personal notes */
