@@ -432,7 +432,8 @@ static gint show_strongs_morph(const gchar * type, const gchar * value,
 	//g_message("buf len = %d",strlen(buf));
 	if(strchr(buf,'|')) {
 		//g_message("buf = %s", buf);
-		for(i=0;i<(strlen(value));i++) {
+		gint valuelen = strlen(value);
+		for (i = 0; i < valuelen; i++) {
 			if(value[i] == '|') {
 				val[i] = '\0';
 				break;
@@ -455,8 +456,9 @@ static gint show_strongs_morph(const gchar * type, const gchar * value,
 	val = g_new(gchar,strlen(morph));
 	if(morph_mod)  {		
 		if(strchr(buf,'|')) {
+			gint morphlen = strlen(morph);
 			g_message("buf = %s", buf);	
-			for(i=0;i<(strlen(morph));i++) {
+			for (i = 0; i < morphlen; i++) {
 				if(morph[i] == '|') {
 					val[i] = '\0';
 					break;
@@ -787,6 +789,7 @@ static gint sword_uri(const gchar * url, gboolean clicked)
 	}
 	
 	work_buf = g_strsplit (url,"/",4);
+	//g_message("work_buf :%s, %s",work_buf[2],work_buf[KEY]);
 	if(!work_buf[2] && !work_buf[KEY]) {
 		alert_url_not_found(url);
 		g_strfreev(work_buf);
@@ -805,12 +808,12 @@ static gint sword_uri(const gchar * url, gboolean clicked)
                              &bytes_written,
                              error);
 	
-	verse_count = backend->is_Bible_key(mykey, settings.currentverse);
-	if(!work_buf[3] && !verse_count){
+	verse_count = 1; //backend->is_Bible_key(mykey, settings.currentverse);
+	/*if(!work_buf[3] && !verse_count){
 		alert_url_not_found(url);
 		g_strfreev(work_buf);
 		return 0;
-	}
+	}*/
 	if(backend->is_module(work_buf[MODULE])) {
 		mod_type = backend->module_type(work_buf[MODULE]);
 		switch(mod_type) {
